---
name: 💡 Feature Request
about: Suggest a new idea/feature
title: '[FEATURE] <description>'
labels: enhancement
assignees: ''

---


**Note: Please search to see if an issue already exists for the feature.**


### Why do we need this improvement?
<!-- Why do we need this improvement? -->

### How will this change help?
<!-- How will this change help? -->

### Please add screenshots if applicable
<!-- Please add screenshots if applicable -->

### How could it be implemented/designed?
<!-- How will it be implemented/designed? -->

### Will this be a breaking change?
<!-- Will this be a breaking change? -->
- [ ] Yes
- [ ] No

### Have you read the Contributing guidelines?
- [ ] I have read the [Contributing guidelines](https://github.com/adamghill/django-unicorn/blob/main/DEVELOPING.md)

### Are you willing to work on this issue?
<!-- This is absolutely not required, but we are happy to guide you in the contribution process. -->
- [ ] Yes I am willing to submit a PR!
- [ ] No, someone else can work on it.

### Anything else:
<!--
Links? References? Anything that will give us more context about the feature you're proposing!
-->

### References:
This document was adapted from the open-source issue templates for Async API